==> cognito-1.104.0-sources.jar: software/amazon/awscdk/services/cognito/StringAttributeProps.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Props for constructing a StringAttr.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:16.068Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.StringAttributeProps")
@software.amazon.jsii.Jsii.Proxy(StringAttributeProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface StringAttributeProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.cognito.StringAttributeConstraints, software.amazon.awscdk.services.cognito.CustomAttributeProps {

    /**
     * @return a {@link Builder} of {@link StringAttributeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StringAttributeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<StringAttributeProps> {
        private java.lang.Number maxLen;
        private java.lang.Number minLen;
        private java.lang.Boolean mutable;

        /**
         * Sets the value of {@link StringAttributeProps#getMaxLen}
         * @param maxLen Maximum length of this attribute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maxLen(java.lang.Number maxLen) {
            this.maxLen = maxLen;
            return this;
        }

        /**
         * Sets the value of {@link StringAttributeProps#getMinLen}
         * @param minLen Minimum length of this attribute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder minLen(java.lang.Number minLen) {
            this.minLen = minLen;
            return this;
        }

        /**
         * Sets the value of {@link StringAttributeProps#getMutable}
         * @param mutable Specifies whether the value of the attribute can be changed.
         *                For any user pool attribute that's mapped to an identity provider attribute, you must set this parameter to true.
         *                Amazon Cognito updates mapped attributes when users sign in to your application through an identity provider.
         *                If an attribute is immutable, Amazon Cognito throws an error when it attempts to update the attribute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder mutable(java.lang.Boolean mutable) {
            this.mutable = mutable;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StringAttributeProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public StringAttributeProps build() {
            return new Jsii$Proxy(maxLen, minLen, mutable);
        }
    }

    /**
     * An implementation for {@link StringAttributeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StringAttributeProps {
        private final java.lang.Number maxLen;
        private final java.lang.Number minLen;
        private final java.lang.Boolean mutable;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.maxLen = software.amazon.jsii.Kernel.get(this, "maxLen", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.minLen = software.amazon.jsii.Kernel.get(this, "minLen", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.mutable = software.amazon.jsii.Kernel.get(this, "mutable", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Number maxLen, final java.lang.Number minLen, final java.lang.Boolean mutable) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.maxLen = maxLen;
            this.minLen = minLen;
            this.mutable = mutable;
        }

        @Override
        public final java.lang.Number getMaxLen() {
            return this.maxLen;
        }

        @Override
        public final java.lang.Number getMinLen() {
            return this.minLen;
        }

        @Override
        public final java.lang.Boolean getMutable() {
            return this.mutable;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getMaxLen() != null) {
                data.set("maxLen", om.valueToTree(this.getMaxLen()));
            }
            if (this.getMinLen() != null) {
                data.set("minLen", om.valueToTree(this.getMinLen()));
            }
            if (this.getMutable() != null) {
                data.set("mutable", om.valueToTree(this.getMutable()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.StringAttributeProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StringAttributeProps.Jsii$Proxy that = (StringAttributeProps.Jsii$Proxy) o;

            if (this.maxLen != null ? !this.maxLen.equals(that.maxLen) : that.maxLen != null) return false;
            if (this.minLen != null ? !this.minLen.equals(that.minLen) : that.minLen != null) return false;
            return this.mutable != null ? this.mutable.equals(that.mutable) : that.mutable == null;
        }

        @Override
        public final int hashCode() {
            int result = this.maxLen != null ? this.maxLen.hashCode() : 0;
            result = 31 * result + (this.minLen != null ? this.minLen.hashCode() : 0);
            result = 31 * result + (this.mutable != null ? this.mutable.hashCode() : 0);
            return result;
        }
    }
}

==> cognito-1.173.0-sources.jar: software/amazon/awscdk/services/cognito/StringAttributeProps.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Props for constructing a StringAttr.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * UserPool.Builder.create(this, "myuserpool")
 *         // ...
 *         .standardAttributes(StandardAttributes.builder()
 *                 .fullname(StandardAttribute.builder()
 *                         .required(true)
 *                         .mutable(false)
 *                         .build())
 *                 .address(StandardAttribute.builder()
 *                         .required(false)
 *                         .mutable(true)
 *                         .build())
 *                 .build())
 *         .customAttributes(Map.of(
 *                 "myappid", StringAttribute.Builder.create().minLen(5).maxLen(15).mutable(false).build(),
 *                 "callingcode", NumberAttribute.Builder.create().min(1).max(3).mutable(true).build(),
 *                 "isEmployee", BooleanAttribute.Builder.create().mutable(true).build(),
 *                 "joinedOn", new DateTimeAttribute()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:33.198Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.StringAttributeProps")
@software.amazon.jsii.Jsii.Proxy(StringAttributeProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface StringAttributeProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.cognito.StringAttributeConstraints, software.amazon.awscdk.services.cognito.CustomAttributeProps {

    /**
     * @return a {@link Builder} of {@link StringAttributeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StringAttributeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<StringAttributeProps> {
        java.lang.Number maxLen;
        java.lang.Number minLen;
        java.lang.Boolean mutable;

        /**
         * Sets the value of {@link StringAttributeProps#getMaxLen}
         * @param maxLen Maximum length of this attribute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maxLen(java.lang.Number maxLen) {
            this.maxLen = maxLen;
            return this;
        }

        /**
         * Sets the value of {@link StringAttributeProps#getMinLen}
         * @param minLen Minimum length of this attribute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder minLen(java.lang.Number minLen) {
            this.minLen = minLen;
            return this;
        }

        /**
         * Sets the value of {@link StringAttributeProps#getMutable}
         * @param mutable Specifies whether the value of the attribute can be changed.
         *                For any user pool attribute that's mapped to an identity provider attribute, you must set this parameter to true.
         *                Amazon Cognito updates mapped attributes when users sign in to your application through an identity provider.
         *                If an attribute is immutable, Amazon Cognito throws an error when it attempts to update the attribute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder mutable(java.lang.Boolean mutable) {
            this.mutable = mutable;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StringAttributeProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public StringAttributeProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link StringAttributeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StringAttributeProps {
        private final java.lang.Number maxLen;
        private final java.lang.Number minLen;
        private final java.lang.Boolean mutable;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.maxLen = software.amazon.jsii.Kernel.get(this, "maxLen", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.minLen = software.amazon.jsii.Kernel.get(this, "minLen", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.mutable = software.amazon.jsii.Kernel.get(this, "mutable", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.maxLen = builder.maxLen;
            this.minLen = builder.minLen;
            this.mutable = builder.mutable;
        }

        @Override
        public final java.lang.Number getMaxLen() {
            return this.maxLen;
        }

        @Override
        public final java.lang.Number getMinLen() {
            return this.minLen;
        }

        @Override
        public final java.lang.Boolean getMutable() {
            return this.mutable;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getMaxLen() != null) {
                data.set("maxLen", om.valueToTree(this.getMaxLen()));
            }
            if (this.getMinLen() != null) {
                data.set("minLen", om.valueToTree(this.getMinLen()));
            }
            if (this.getMutable() != null) {
                data.set("mutable", om.valueToTree(this.getMutable()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.StringAttributeProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StringAttributeProps.Jsii$Proxy that = (StringAttributeProps.Jsii$Proxy) o;

            if (this.maxLen != null ? !this.maxLen.equals(that.maxLen) : that.maxLen != null) return false;
            if (this.minLen != null ? !this.minLen.equals(that.minLen) : that.minLen != null) return false;
            return this.mutable != null ? this.mutable.equals(that.mutable) : that.mutable == null;
        }

        @Override
        public final int hashCode() {
            int result = this.maxLen != null ? this.maxLen.hashCode() : 0;
            result = 31 * result + (this.minLen != null ? this.minLen.hashCode() : 0);
            result = 31 * result + (this.mutable != null ? this.mutable.hashCode() : 0);
            return result;
        }
    }
}
